@@ -1,5 +1,7 @@
 # Component + Residual Plots (J. Fox)
 
+# last modified 2 April 02 by J. Fox
+
 crp<-function(...) cr.plots(...)
 
 cr.plots<-function(model, variable, ask=missing(variable), one.page=!ask, span=.5, ...){
@@ -47,10 +49,10 @@ cr.plot<-function (model, ...) {
     }
 
 
-cr.plot.lm<-function(model, variable, order=1, line=T, smooth=T,
-    iter, span=.5, las=1, col=palette()[2], pch=1, lwd=2,
+cr.plot.lm<-function(model, variable, order=1, line=TRUE, smooth=TRUE,
+    iter, span=.5, las=par("las"), col=palette()[2], pch=1, lwd=2,
     main="Component+Residual Plot") {
-    # last modified 2 Aug 2001 by J. Fox
+    # last modified 20 Feb 2002 by J. Fox
     # method also works for glm objects
     if(!is.null(class(model$na.action)) && 
         class(model$na.action) == 'exclude') class(model$na.action) <- 'omit'
